# template_fill

Template fill provides the utility `template_fill` that receives a template
file with Jinja syntax and a set of file with json data and outputs the
template completed with the json data.

## Installation

* From pypi:

```
    pip install m2-beats2audio
```

## Usage

* template_fill template_file data_files... > completed_file
